@@ -20,6 +20,8 @@
 #ifndef GRAPHICSVIEW_H
 #define GRAPHICSVIEW_H
 
+#include "graphicsscene.h"
+
 #include <QtGui/QGraphicsView>
 
 
@@ -27,9 +29,16 @@ class GraphicsView : public QGraphicsView
 {
 	public:
 		GraphicsView(QWidget* parent = 0);
-		~GraphicsView() {};
+		~GraphicsView();
 		
 		virtual void showEvent (QShowEvent* event);
+		void changeLevel();
+		void restartGame();
+// 		void askUserName();
+		void statistics();
+		void changeShape();
+	private:
+		GraphicsScene* scene;
 };
 
 #endif // GRAPHICSVIEW_H
