@@ -31,7 +31,7 @@ class Shape : public QGraphicsWidget
 		void addData(int kindOfData, int value);
 		int getData(int kindOfData);
 		void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget);
-		
+		void defineShapeImage(int kind, QChar letter);
 	private:
 		enum DataInside {
 			Positions, Shapes
@@ -46,6 +46,8 @@ class Shape : public QGraphicsWidget
 			Human, // Human
 			Img
 		};
+		QString imgMachine;
+		QString imgHuman;
 };
 
 #endif // SHAPE_H
